@@ -206,6 +206,7 @@ sub _parse_line {
 ########################################
 # search for a token and return first occurance, trim that part from string
 sub _strtok {
+    return '' unless defined $_[1];
     my $index = index($_[1], $_[2]);
     if($index != -1) {
         my $value = substr($_[1], 0, $index, '');
@@ -265,7 +266,9 @@ sub _set_from_options {
     }
 
     # Timeperiod Transitions
-    elsif($data->{'type'} eq 'TIMEPERIOD TRANSITION') {
+    # livestatus does not parse this correct, so we have to use regex
+    elsif($data->{'type'} =~ m/^TIMEPERIOD\ TRANSITION/mx) {
+        $data->{'type'}       = 'TIMEPERIOD TRANSITION';
         $data->{'timeperiod'} = $self->_strtok($string, ';');
         $data->{'from'}       = $self->_strtok($string, ';');
         $data->{'to'}         = $self->_strtok($string, ';');
